import { Story, Canvas, Meta, Description } from "@storybook/addon-docs/blocks";
import { html } from "lit-html";
import readme from "../../dist/docs/components/filter/readme.md";
import CATEGORIES from "../categories";

<Meta title={CATEGORIES.COMPONENTS + "Filter"} />

# Filter

These are examples for using filters.

## Static Filter

<Canvas
    mdxSource={`
        <ui-filter>
            <div class="row">
                <div class="gr-10">
                    <div class="row">
                        <div class="gr-4">
                            <ui-dropdown label="Filter 1" filterable="true">
                                <ui-checkbox-list-item value="val_1" label="Entry 1"></ui-checkbox-list-item>
                                <ui-checkbox-list-item value="val_2" label="Entry 2"></ui-checkbox-list-item>
                                <ui-checkbox-list-item value="val_3" label="Entry 3"></ui-checkbox-list-item>
                                <ui-checkbox-list-item value="val_4" label="Entry 4"></ui-checkbox-list-item>
                            </ui-dropdown>
                        </div>
                        <div class="gr-4">
                            <ui-dropdown label="Filter 2" filterable="true">
                                <ui-checkbox-list-item value="val_1" label="Entry 5"></ui-checkbox-list-item>
                                <ui-checkbox-list-item value="val_2" label="Entry 6"></ui-checkbox-list-item>
                                <ui-checkbox-list-item value="val_3" label="Entry 7"></ui-checkbox-list-item>
                                <ui-checkbox-list-item value="val_4" label="Entry 8"></ui-checkbox-list-item>
                            </ui-dropdown>
                        </div>
                        <div class="gr-4">
                            <ui-dropdown label="Filter 3" filterable="true">
                                <ui-checkbox-list-item value="val_1" label="Entry 9"></ui-checkbox-list-item>
                                <ui-checkbox-list-item value="val_2" label="Entry 10"></ui-checkbox-list-item>
                                <ui-checkbox-list-item value="val_3" label="Entry 11"></ui-checkbox-list-item>
                                <ui-checkbox-list-item value="val_4" label="Entry 12"></ui-checkbox-list-item>
                            </ui-dropdown>
                        </div>
                    </div>
                </div>
                <div class="gr-2">
                    <button type="submit" class="ui-button ui-button--green">Apply</button>
                </div>
            </div>
            <div class="row">
                <div class="gr-12">
                    <div class="ui-tag-list"></div>
                </div>
            </div>
        </ui-filter>
    `}
>
    <Story name="Static Filter" height="250px" parameters={{jest: ['filter.e2e.ts'] }}>
        {html`
            <ui-filter>
                <div class="row">
                    <div class="gr-10">
                        <div class="row">
                            <div class="gr-4">
                                <ui-dropdown label="Filter 1" filterable="true">
                                    <ui-checkbox-list-item value="val_1" label="Entry 1"></ui-checkbox-list-item>
                                    <ui-checkbox-list-item value="val_2" label="Entry 2"></ui-checkbox-list-item>
                                    <ui-checkbox-list-item value="val_3" label="Entry 3"></ui-checkbox-list-item>
                                    <ui-checkbox-list-item value="val_4" label="Entry 4"></ui-checkbox-list-item>
                                </ui-dropdown>
                            </div>
                            <div class="gr-4">
                                <ui-dropdown label="Filter 2" filterable="true">
                                    <ui-checkbox-list-item value="val_1" label="Entry 5"></ui-checkbox-list-item>
                                    <ui-checkbox-list-item value="val_2" label="Entry 6"></ui-checkbox-list-item>
                                    <ui-checkbox-list-item value="val_3" label="Entry 7"></ui-checkbox-list-item>
                                    <ui-checkbox-list-item value="val_4" label="Entry 8"></ui-checkbox-list-item>
                                </ui-dropdown>
                            </div>
                            <div class="gr-4">
                                <ui-dropdown label="Filter 3" filterable="true">
                                    <ui-checkbox-list-item value="val_1" label="Entry 9"></ui-checkbox-list-item>
                                    <ui-checkbox-list-item value="val_2" label="Entry 10"></ui-checkbox-list-item>
                                    <ui-checkbox-list-item value="val_3" label="Entry 11"></ui-checkbox-list-item>
                                    <ui-checkbox-list-item value="val_4" label="Entry 12"></ui-checkbox-list-item>
                                </ui-dropdown>
                            </div>
                        </div>
                    </div>
                    <div class="gr-2">
                        <button type="submit" class="ui-button ui-button--green">Apply</button>
                    </div>
                </div>
                <div class="row">
                    <div class="gr-12">
                        <!-- This hr creates a large spacing to the top. Who the hell knows why!! TODO: remove stlye and reset the hr. This will be obsolete anyway when we rethink the integration of the web styleguide. -->
                        <hr style="margin: 1em 0;" />
                    </div>
                </div>
                <div class="row">
                    <div class="gr-12">
                        <div class="ui-tag-list"></div>
                    </div>
                </div>
            </ui-filter>
        `}
    </Story>
</Canvas>

## Dynamic Filter

<Canvas>
    <Story name="Dynamic Filter" height="350px">
        {html`
            <ui-filter endpoint="/mock-data/filter-backend.json">
                <div class="row">
                    <div class="gr-10">
                        <div class="row">
                            <div class="gr-4">
                                <ui-dropdown name="filter1" label="Filter 1" filterable></ui-dropdown>
                            </div>
                            <div class="gr-4">
                                <ui-dropdown name="filter2" label="Filter 2" filterable></ui-dropdown>
                            </div>
                            <div class="gr-4">
                                <ui-dropdown name="filter3" label="Filter 3" filterable></ui-dropdown>
                            </div>
                        </div>
                    </div>
                    <div class="gr-2">
                        <button type="submit" class="btn btn-green">Apply</button>
                    </div>
                </div>
                <div class="row">
                    <div class="gr-12">
                        <!-- This hr creates a large spacing to the top. Who the hell knows why!! TODO: remove stlye and reset the hr. This will be obsolete anyway when we rethink the integration of the web styleguide. -->
                        <hr style="margin: 1em 0;" />
                    </div>
                </div>
                <div class="row">
                    <div class="gr-12">
                        <div class="ui-tag-list"></div>
                    </div>
                </div>
            </ui-filter>
        `}
    </Story>
</Canvas>

# Developer Documentation

<Description markdown={readme} />
